@@ -1,9 +1,9 @@
 package Text::Table::Sprintf;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-02'; # DATE
+our $DATE = '2021-04-06'; # DATE
 our $DIST = 'Text-Table-Sprintf'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 #IFUNBUILT
 # # use strict;
@@ -116,7 +116,7 @@ Text::Table::Sprintf - Generate simple text tables from 2D arrays using sprintf(
 
 =head1 VERSION
 
-This document describes version 0.002 of Text::Table::Sprintf (from Perl distribution Text-Table-Sprintf), released on 2021-04-02.
+This document describes version 0.003 of Text::Table::Sprintf (from Perl distribution Text-Table-Sprintf), released on 2021-04-06.
 
 =head1 SYNOPSIS
 
@@ -158,6 +158,190 @@ table will not be correctly formatted (cells might move to another row/column).
 
 =for Pod::Coverage ^(max)$
 
+=head1 DECLARED FEATURES
+
+Features declared by this module:
+
+=head2 From feature set TextTable
+
+Features from feature set L<TextTable|Module::Features::TextTable> declared by this module:
+
+=over
+
+=item * can_align_cell_containing_color_code
+
+Value: no.
+
+=item * can_align_cell_containing_newline
+
+Value: no.
+
+=item * can_align_cell_containing_wide_character
+
+Value: no.
+
+=item * can_color
+
+Can produce colored table.
+
+Value: no.
+
+=item * can_color_theme
+
+Allow choosing colors from a named set of palettes.
+
+Value: no.
+
+=item * can_colspan
+
+Value: no.
+
+=item * can_customize_border
+
+Let user customize border character in some way, e.g. selecting from several available borders, disable border.
+
+Value: no.
+
+=item * can_halign
+
+Provide a way for user to specify horizontal alignment (leftE<sol>middleE<sol>right) of cells.
+
+Value: no.
+
+=item * can_halign_individual_cell
+
+Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual cells.
+
+Value: no.
+
+=item * can_halign_individual_column
+
+Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual columns.
+
+Value: no.
+
+=item * can_halign_individual_row
+
+Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual rows.
+
+Value: no.
+
+=item * can_hpad
+
+Provide a way for user to specify horizontal padding of cells.
+
+Value: no.
+
+=item * can_hpad_individual_cell
+
+Provide a way for user to specify different horizontal padding of individual cells.
+
+Value: no.
+
+=item * can_hpad_individual_column
+
+Provide a way for user to specify different horizontal padding of individual columns.
+
+Value: no.
+
+=item * can_hpad_individual_row
+
+Provide a way for user to specify different horizontal padding of individual rows.
+
+Value: no.
+
+=item * can_rowspan
+
+Value: no.
+
+=item * can_set_cell_height
+
+Allow setting height of rows.
+
+Value: no.
+
+=item * can_set_cell_height_of_individual_row
+
+Allow setting height of individual rows.
+
+Value: no.
+
+=item * can_set_cell_width
+
+Allow setting height of rows.
+
+Value: no.
+
+=item * can_set_cell_width_of_individual_column
+
+Allow setting height of individual rows.
+
+Value: no.
+
+=item * can_use_box_character
+
+Can use terminal box-drawing character when drawing border.
+
+Value: no.
+
+=item * can_valign
+
+Provide a way for user to specify vertical alignment (topE<sol>middleE<sol>bottom) of cells.
+
+Value: no.
+
+=item * can_valign_individual_cell
+
+Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual cells.
+
+Value: no.
+
+=item * can_valign_individual_column
+
+Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual columns.
+
+Value: no.
+
+=item * can_valign_individual_row
+
+Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual rows.
+
+Value: no.
+
+=item * can_vpad
+
+Provide a way for user to specify vertical padding of cells.
+
+Value: no.
+
+=item * can_vpad_individual_cell
+
+Provide a way for user to specify different vertical padding of individual cells.
+
+Value: no.
+
+=item * can_vpad_individual_column
+
+Provide a way for user to specify different vertical padding of individual columns.
+
+Value: no.
+
+=item * can_vpad_individual_row
+
+Provide a way for user to specify different vertical padding of individual rows.
+
+Value: no.
+
+=item * speed
+
+Subjective speed rating, relative to other text table modules.
+
+Value: "fast".
+
+=back
+
+For more details on module features, see L<Module::Features>.
+
 =head1 FUNCTIONS
 
 =head2 table
